@@ -1,7 +1,7 @@
 /*
  *  eCoach
  *
- *  Copyright (C) 2008  Jukka Alasalmi
+ *  Copyright (C) 2009  Jukka Alasalmi, Sampo Savola
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -48,13 +48,13 @@ typedef enum _AnalyzerViewType {
 
 typedef enum _AnalyzerViewInfoLabel {
 	ANALYZER_VIEW_INFO_LABEL_NAME,
-	ANALYZER_VIEW_INFO_LABEL_COMMENT,
 	ANALYZER_VIEW_INFO_LABEL_TIME_START,
 	ANALYZER_VIEW_INFO_LABEL_TIME_END,
 	ANALYZER_VIEW_INFO_LABEL_DURATION,
 	ANALYZER_VIEW_INFO_LABEL_DISTANCE,
 	ANALYZER_VIEW_INFO_LABEL_SPEED_AVG,
 	ANALYZER_VIEW_INFO_LABEL_SPEED_MAX,
+	ANALYZER_VIEW_INFO_LABEL_MIN_PER_KM,
 	ANALYZER_VIEW_INFO_LABEL_HEART_RATE_AVG,
 	ANALYZER_VIEW_INFO_LABEL_HEART_RATE_MAX,
 	ANALYZER_VIEW_INFO_LABEL_COUNT
@@ -73,12 +73,17 @@ typedef struct _AnalyzerView {
 	GConfHelperData *gconf_helper;
 
 	GtkWidget *btn_back;
-
+  
+	GtkWidget *map_win;
 	gchar *default_folder_name;
 
 	/* Following members are created when the view is shown and destroyed
 	 * when the view is hidden */
 
+	GtkWidget *win;
+	GtkWidget *vbox;
+	GtkWidget *main_table;
+	GtkWidget *btn_map;
 	GtkWidget *btn_open;
 	GtkWidget *btn_track_prev;
 	GtkWidget *btn_track_next;
@@ -86,7 +91,7 @@ typedef struct _AnalyzerView {
 	GtkWidget *lbl_track_details;
 
 	GtkWidget *scrolled;
-
+	GtkWidget *pannable;
 	/* Container for the different views */
 	GtkWidget *fixed_view;
 
@@ -98,6 +103,9 @@ typedef struct _AnalyzerView {
 	GtkWidget *btn_view_next;
 	GtkWidget *lbl_view_name;
 
+	GtkWidget *pan;
+	GtkWidget *data;
+	
 	/* Data for info view */
 	GtkWidget *info_table;
 
@@ -121,6 +129,16 @@ typedef struct _AnalyzerView {
 	gboolean show_heart_rate;
 
 	gboolean metric;
+	
+	/*map */
+	const char *friendly_name;
+	char *cachedir;
+	gboolean fullpath;
+	gint map_provider;
+	GtkWidget *map;
+	gdouble lat,lon;
+	GdkPixbuf *zoom_in;
+	GdkPixbuf *zoom_out;
 	/* Data that is parsed from tracks */
 
 	/**
