@@ -146,6 +146,7 @@ static void data_rec_btn_press_cb(GtkWidget *widget, GdkEventButton *event, gpoi
 static void data_pause_btn_press_cb(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 static void add_note_cb(HildonButton *button, gpointer user_data);
 static void info_speed_clicked(GtkWidget *button, gpointer user_data);
+static void destroy_personal_data_dlg (GtkWidget *widget,GdkEvent  *event,gpointer user_data);
 /*****************************************************************************
  * Function declarations                                                     *
  *****************************************************************************/
@@ -175,7 +176,7 @@ MapView *map_view_new(
 	self->beat_detector = beat_detector;
 	self->osso = osso;
 	self->track_helper = track_helper_new();
-
+	self->first_location_point_added = FALSE;
 
 
 
@@ -416,6 +417,8 @@ gboolean map_view_setup_activity(
 
 	self->heart_rate_limit_low = heart_rate_limit_low;
 	self->heart_rate_limit_high = heart_rate_limit_high;
+	DEBUG("HR LIMIT LOW %d", self->heart_rate_limit_low);
+	DEBUG("HR LIMIT HIGH %d", self->heart_rate_limit_high);
 	self->add_calendar = add_calendar;
 
 	DEBUG_END();
@@ -932,17 +935,21 @@ static void map_view_heart_rate_changed(
 	DEBUG_BEGIN();
 
 	if(heart_rate >= 0)
+	{
+	if(gtk_window_is_active(GTK_WINDOW(self->data_win)))
 	{
 		text = g_strdup_printf(_("%d bpm"), (gint)heart_rate);
+		
+		
 		ec_button_set_label_text(
 				EC_BUTTON(self->info_heart_rate),
 	 			text);
-		gtk_label_set_text(GTK_LABEL(self->info_heart_rate),text);
+		//gtk_label_set_text(GTK_LABEL(self->info_heart_rate),text);
 		g_free(text);
 
 		map_view_update_heart_rate_icon(self, heart_rate);
-
-		if(self->activity_state == MAP_VIEW_ACTIVITY_STATE_STARTED)
+	}
+		if(self->activity_state == MAP_VIEW_ACTIVITY_STATE_STARTED && self->first_location_point_added)
 		{
 			self->heart_rate_count++;
 			if(self->heart_rate_count == 10)
@@ -1001,6 +1008,7 @@ static void map_view_location_changed(
 			self->curr_speed = device->fix->speed;
 			map_view_check_and_add_route_point(self, &point,
 					device->fix);
+			self->first_location_point_added = TRUE;
 			DEBUG("SPEED ACCURACY %.5f",device->fix->eps);
 			
 			osm_gps_map_draw_gps(OSM_GPS_MAP(self->map),device->fix->latitude,device->fix->longitude,0);
@@ -1153,6 +1161,7 @@ static void map_view_btn_start_pause_clicked(GtkWidget *button,
 			osm_gps_map_remove_button((OsmGpsMap*)self->map,421, 346);
 			osm_gps_map_add_button((OsmGpsMap*)self->map,421, 346, self->rec_btn_selected);
 			osm_gps_map_clear_gps(OSM_GPS_MAP(self->map));
+			self->first_location_point_added = FALSE;
 			break;
 	}
 
@@ -1656,7 +1665,9 @@ if(!self->fullscreen){
 	  DEBUG("DATA BUTTON");
 	//  gtk_widget_hide(self->map);
 	  map_view_show_data(self);
-
+	  DEBUG_END();
+	 return FALSE;
+	 
 	}
 
 	if(event->x < 80 && (event->y > 150 && event->y < 240)){
@@ -1954,9 +1965,22 @@ toggle_map_centering(HildonCheckButton *button, gpointer user_data)
 
     DEBUG_END();
 }
+static void destroy_personal_data_dlg (GtkWidget *widget,GdkEvent  *event,gpointer user_data)
+{
+  MapView *self = (MapView *)user_data;
+  DEBUG_BEGIN();
+  gtk_widget_destroy(self->personal_win);
+  if(self->fullscreen){
+      osm_gps_map_show_buttons(OSM_GPS_MAP(self->map));
+      gtk_window_unfullscreen ((GtkWindow*)self->win);
+      gtk_widget_set_size_request(self->map,800,420);
+    self->fullscreen = FALSE;
+  }
+  DEBUG_END();
+}
 static void personal_data_dlg(HildonButton *button, gpointer user_data){
 
-	GtkWidget *win;
+	
 	GtkWidget *fixed;
 	GtkWidget *scale;
 	GtkWidget *anaerobic;
@@ -1988,8 +2012,10 @@ aerobic = gtk_image_new_from_file(GFXDIR "personal_data_button.png");
 weight_control = gtk_image_new_from_file(GFXDIR "personal_data_button.png");
 moder_ex = gtk_image_new_from_file(GFXDIR "personal_data_button.png");
 
-win = hildon_stackable_window_new();
-gtk_window_set_title ( GTK_WINDOW (win), "eCoach >Personal Data");
+self->personal_win = hildon_stackable_window_new();
+g_signal_connect(self->personal_win, "delete-event", G_CALLBACK(destroy_personal_data_dlg), self);
+
+gtk_window_set_title ( GTK_WINDOW (self->personal_win), "eCoach >Personal Data");
 fixed = gtk_fixed_new();
 
 desc = pango_font_description_new();
@@ -2110,8 +2136,8 @@ for(int i=0; i<4;i++){
 }
 
 
-gtk_container_add (GTK_CONTAINER (win),fixed);
-gtk_widget_show_all(win);
+gtk_container_add (GTK_CONTAINER (self->personal_win),fixed);
+gtk_widget_show_all(self->personal_win);
 	DEBUG_END();
 
 }
@@ -2122,7 +2148,7 @@ static void about_dlg(HildonButton *button, gpointer user_data){
     gtk_show_about_dialog((GtkWindow*)self->win
                 , "name",      "eCoach"
 		, "logo-icon-name",	"ecoach"
-                , "version",   "1.54"
+                , "version",   "1.55"
                 , "copyright", "Sampo Savola <samposav@paju.oulu.fi>\n"
 		"Jukka Alasalmi\n Veli-Pekka Haajanen\n Kai Skiftesvik"
                 , "website",   "http://ecoach.garage.maemo.org"
